.CodeFlask{
    position:relative;
    overflow:hidden;
}

.CodeFlask__textarea,
.CodeFlask__pre, 
code[class*="language-"], 
pre[class*="language-"]{
    box-sizing:border-box;
    position:absolute;
    top:0;
    left:0;
    width:100%;
    padding:1rem !important;
    border:none;
    font-family: Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace;
    font-size:13px;
    background:transparent;
    white-space:pre-wrap !important;
    line-height:1.5em;
    word-wrap: break-word;
}

.CodeFlask__textarea{
    border:none;
    background:transparent;
    outline:none;
    resize:none;
    opacity:0.4;
    color:#000;
    margin:0;
    z-index:1;
    height:100%;
    -webkit-overflow-scrolling: touch;
    -webkit-text-fill-color: transparent;
    tab-size: 4;
}

.CodeFlask__pre{
    z-index:2;
    pointer-events:none;
    overflow-y:auto;
    margin:0;
    min-height:100%;
    margin:0 !important;
    background:transparent !important;
}

.CodeFlask__code{
    font-size:inherit;
    font-family:inherit;
    color:inherit;
    display:block;
}

.CodeFlask__is-code {
    white-space: pre;
}

.CodeFlask__textarea_line-numbers {
    width: calc(100% - 3.8em);
    margin-left: 3.8em;
    padding-left: 0px !important;
}

.CodeFlask__pre_line-numbers {
    padding-left: 3.8em !important;
}
