.token.prolog, .token.tag, .token.punctuation { color: #5755d9; }

.token.attr-value, .token.string { color: #32b643; }

.token.number { color: #e85600; }

.token.attr-name { color: #50596c; }

.toast { border-radius: 0px; }

.fixed { position: fixed; top: 0; z-index: 9999; }

body { font-size: 16px; }

header { background: #5755d9; height: 60px; }

header .container { text-align: center; }

header .container #logo { position: relative; display: inline-block; margin-top: 15px; padding-left: 10px; color: #fff; -moz-transition: color, 0.3s; -o-transition: color, 0.3s; -webkit-transition: color, 0.3s; transition: color, 0.3s; }

header .container #logo img { position: absolute; top: 3px; left: -30px; width: 30px; height: 30px; }

header .container #logo:hover { color: #e5e5f9; text-decoration: none; }

.btn.icon-and-text .ion { margin-right: 8px; }

#body { margin-top: 20px; }

#resource_list .resource { margin-top: 20px; /* product list */ }

#resource_list .resource .resource_head h4 { margin: 0px; display: inline-block; font-size: 20px; }

#resource_list .resource .resource_head span { display: inline-block; color: #5755d9; margin-left: 5px; }

#resource_list .resource .resource_head .btn { border: none; padding: 0 10px; }

#resource_list .resource .resource_head a.btn { padding: 7px 10px 0 10px; }

#resource_list .resource .divider { margin: 0; }

#resource_list .resource .create_resource_head { margin: 0 0 10px 0; }

#resource_list .resource .create_resource_head .new-resource-input, #resource_list .resource .create_resource_head .new-url-input { border-color: #fff; }

#resource_list .resource .create_resource_head .new-resource-input:hover, #resource_list .resource .create_resource_head .new-url-input:hover { border-color: #5755d9; }

#resource_list .resource .create_resource_head .new-resource-input { font-size: 20px; }

#resource_list .resource .create_resource_head .new-url-input { margin-left: 5px; color: #5755d9; }

#resource_list .resource .create_resource_head .btn { margin-left: 10px; }

#resource_list .resource .action_list .card { margin-top: 10px; color: #50596c; -moz-transition: border-color 0.3s; -o-transition: border-color 0.3s; -webkit-transition: border-color 0.3s; transition: border-color 0.3s; }

#resource_list .resource .action_list .card .card-title { -moz-transition: color 0.3s; -o-transition: color 0.3s; -webkit-transition: color 0.3s; transition: color 0.3s; }

#resource_list .resource .action_list .card .card-header .card-subtitle { color: #8f99ac; font-size: 12px; }

#resource_list .resource .action_list .card:hover { text-decoration: none; border-color: #5755d9; }

#resource_list .resource .action_list .card:hover .card-title { color: #5755d9; }

#resource_list .resource .action_list .card.create-new-card { background: #f8f9fa; height: 126px; }

#resource_list .resource .action_list .card.create-new-card .card-header { -moz-transition: color, 0.3s; -o-transition: color, 0.3s; -webkit-transition: color, 0.3s; transition: color, 0.3s; text-align: center; color: #9ea6b7; }

#resource_list .resource .action_list .card.create-new-card .card-header .ion { margin-top: 6px; font-size: 50px; }

#resource_list .resource .action_list .card.create-new-card .card-header h4 { margin-top: 5px; font-weight: 400; }

#resource_list .resource .action_list .card.create-new-card:hover { border-color: #818ba1; }

#resource_list .resource .action_list .card.create-new-card:hover .card-header { color: #818ba1; }

footer .container { padding: 10px 0 60px 0; text-align: center; font-size: 12px; }

footer .container #whoiam { color: #bbc1cd; }

footer .container #whoiam a { color: #bbc1cd; }

footer .container #whoiam a img { width: 20px; height: 16px; }

#action-edit-form .title-input { font-size: 20px; }

#action-edit-form .url-input { color: #5755d9; }

#action-edit-form .select-box { margin: 0px; }

#action-edit-form .select-box .form-group-gap { margin-left: 10px; }

#action-edit-form .type-response-area { margin-top: 20px; }

#action-edit-form .type-response-area.has-error #response { border-color: #e85600; }

#action-edit-form .type-response-area .response-label { display: block; padding: 5px 0; }

#action-edit-form .type-response-area #response { border: 1px solid #caced7; }

#action-view .breadcrumb-item a { color: #5755d9; text-decoration: underline; }

#action-view .detail .detail-header { margin-top: 10px; }

#action-view .detail .detail-header h3 { display: inline-block; margin: 0px; font-size: 20px; }

#action-view .detail .detail-header .url { color: #5755d9; }

#action-view .detail .detail-header .btn { position: relative; top: -1px; padding: 5px 8px; height: 30px; border: none; float: right; }

#action-view .detail .detail-chips { margin-top: 10px; }

#action-view .response-area { margin-top: 30px; }

#action-view .response-area pre { margin: 5px 0 0 0; }

#action-view .response-area pre code { color: #50596c; background: none; }

#action-view .tools .btn.btn-danger { border-color: #d3d2f5; color: #807fe2; }

/* components */
.btn { cursor: pointer; }

/*# sourceMappingURL=../../../../../../../../static/styles/main.css.map */