$main-color: #337AF6;
$background-color: #F3F5F8;
$header-color: $main-color;
$default-text-color: #50596c;

$label-green-bg: #DBF1DD;
$label-green: #5D985D;

$label-yellow-bg: #F0F1DB;
$label-yellow: #98985D; 

$label-blue-bg: #DBE8F1;
$label-blue: #5D7E98;

$label-red-bg: #F1DBDB;
$label-red: #985D5D;

$text-primary: #5755d9;
$text-primary-hover: #4240d4;

$text-secondary: #e5e5f9;
$text-secondary-hover: #d1d0f4;

$text-gray: #acb3c2;
$text-gray-hover: #9ea6b7;

$text-light: #fff;
$text-light-hover: #f2f2f2;

$text-success: #32b643;
$text-success-hover: #2da23c;

$text-warning: #ffb700;
$text-warning-hover: #e6a500;

$text-error: #e85600;
$text-error-hover: #cf4d00;

$bg-primary: $text-primary;
$bg-secondary: #f1f1fc;
$bg-dark: #454d5d;
$bg-gray: #f8f9fa;
$bg-success: $text-success;
$bg-warning: $text-warning;
$bg-error: $text-error;