<div class="toast container">
    <div class="columns">
        <div class="column col-9 col-mx-auto">
            <button class="btn btn-clear float-right"></button>
            {{ message | escape }}
        </div>
    </div>
</div>