# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-11-18 04:52
from __future__ import unicode_literals

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0003_auto_20171118_0452'),
    ]

    operations = [
        migrations.AlterField(
            model_name='action',
            name='created_at',
            field=models.DateTimeField(default=datetime.datetime(2017, 11, 18, 4, 52, 18, 606440)),
        ),
    ]
